@@ -19,6 +19,8 @@ class Client:
         sock.connect((self.ip, self.socket_port))
         sock.sendall(data)
         data = sock.recv(buffer_size)
+        while not len(data):
+          data = sock.recv(buffer_size)
     except ConnectionRefusedError:
       print('Jeff\'s socket is disabled.')
     return data
@@ -58,4 +60,4 @@ class Client:
     if "memory_values" not in j:
       return None
     else:
-      return j
+      return j["memory_values"]
