@@ -19,6 +19,9 @@ class Server:
     except json.decoder.JSONDecodeError:
       print('JSON decode error.')
       return b"{}"
+    except UnicodeDecodeError:
+      print('Unicode decode error.')
+      return b"{}"
   
   def _encode_json(j):
     return json.dumps(j).encode()
